//
//  MPDataCenterTestCase.m
//  MPDataCenterDemo
//
//  Created by kuoxuan on 2019/2/27.
//  Copyright © 2019 alipay. All rights reserved.
//

#import "MPDataCenterTestCase.h"
#import <MPDataCenter/MPDataCenter.h>
#import <MPBaseTest/MPBaseUtil.h>

# define  dataBusiness @"dataTestCase"

@protocol DemoProtocol <APDAOProtocol>
- (APDAOResult*)insertItem:(NSString*)content;
- (NSString*)getItem:(NSNumber*)index;
@end

@implementation MPDataCenterTestCase


+ (void)runKVStorageTest
{
    [APCommonPreferences setInteger:11 forKey:@"intkey" business:dataBusiness];
    NSInteger intValue = [APCommonPreferences integerForKey:@"intkey" business:dataBusiness];
    assert(intValue == 11);
    MPAdapterLog(@"MPAdapter", @"DataCenter", @"%@", @"Integer存储检测通过");
    
    [APCommonPreferences setDouble:11.11 forKey:@"doubleKey" business:dataBusiness];
    double doubleValue = [APCommonPreferences doubleForKey:@"doubleKey" business:dataBusiness];
    assert(doubleValue == 11.11);
    MPAdapterLog(@"MPAdapter", @"DataCenter", @"%@", @"Double存储检测通过");
    
    [APCommonPreferences setString:@"helloDataCenter" forKey:@"strKey" business:dataBusiness];
    NSString *str = [APCommonPreferences stringForKey:@"strKey" business:dataBusiness];
    assert([str isEqualToString:@"helloDataCenter"]);
    MPAdapterLog(@"MPAdapter", @"DataCenter", @"%@", @"String存储检测通过");
    
    [APCommonPreferences setObject:@{@"hello": @"data"} forKey:@"plistObjectKey" business:dataBusiness];
    NSDictionary *dict = [APCommonPreferences objectForKey:@"plistObjectKey" business:dataBusiness];
    assert([@"data" isEqualToString:[dict objectForKey:@"hello"]]);
    MPAdapterLog(@"MPAdapter", @"DataCenter", @"%@", @"PList对象存储检测通过");
    
    MPCodingData *obj = [MPCodingData new];
    obj.name = @"hello";
    obj.age = 12;
    [APCommonPreferences archiveObject:obj forKey:@"archObjKey" business:dataBusiness];
    MPCodingData *encodeObj = [APCommonPreferences objectForKey:@"archObjKey" business:dataBusiness];
    assert([encodeObj.name isEqualToString:@"hello"] && encodeObj.age == 12);
    MPAdapterLog(@"MPAdapter", @"DataCenter", @"%@", @"Archive对象存储检测通过");
    
}


+ (void)runLRUTest
{
    APLRUMemoryCache *mCache = [[APLRUMemoryCache alloc] initWithCapacity:10];
    [mCache setObject:@"vv" forKey:@"key"];
    NSString *str = [mCache objectForKey:@"key"];
    assert([str isEqualToString:@"vv"]);
    MPAdapterLog(@"MPAdapter", @"DataCenter", @"%@", @"LRU Memory检测通过");
    
    APLRUDiskCache *dCache = [[APLRUDiskCache alloc] initWithName:@"diskCache" capacity:100 userDependent:NO crypted:NO];
    [dCache setObject:@"vvd" forKey:@"key"];
    assert([@"vvd" isEqualToString:[dCache objectForKey:@"key"]]);
    MPAdapterLog(@"MPAdapter", @"DataCenter", @"%@", @"LRU Disk检测通过");
}

@end


@implementation MPCodingData

- (void)encodeWithCoder:(NSCoder *)aCoder
{
    [aCoder encodeObject:self.name forKey:@"name"];
    [aCoder encodeInteger:self.age forKey:@"age"];
}

- (instancetype)initWithCoder:(NSCoder *)aDecoder
{
    MPCodingData *data = [MPCodingData new];
    data.name = [aDecoder decodeObjectForKey:@"name"];
    data.age = [aDecoder decodeIntegerForKey:@"age"];
    return data;
}

@end
